@@ -1,5 +1,5 @@
 package Business::PayPal::API::ExpressCheckout;
-$Business::PayPal::API::ExpressCheckout::VERSION = '0.75';
+$Business::PayPal::API::ExpressCheckout::VERSION = '0.76';
 use 5.008001;
 use strict;
 use warnings;
@@ -182,7 +182,7 @@ sub GetExpressCheckoutDetails {
             Payer           => 'PayerInfo/Payer',
             PayerID         => 'PayerInfo/PayerID',
             PayerStatus     => 'PayerInfo/PayerStatus',
-            Salutation      => 'PayerInfo/PayerName/Saluation',
+            Salutation      => 'PayerInfo/PayerName/Salutation',
             FirstName       => 'PayerInfo/PayerName/FirstName',
             MiddleName      => 'PayerInfo/PayerName/MiddleName',
             LastName        => 'PayerInfo/PayerName/LastName',
@@ -404,7 +404,7 @@ Business::PayPal::API::ExpressCheckout - PayPal Express Checkout API
 
 =head1 VERSION
 
-version 0.75
+version 0.76
 
 =head1 SYNOPSIS
 
